@@ -1,9 +1,18 @@
 package Syntax::Keyword::Junction::Base;
-
 use strict;
 use warnings;
 
-our $VERSION = '0.003007'; # VERSION
+our $VERSION = '0.003009';
+
+BEGIN {
+  *_WANT_SMARTMATCH = ("$]" >= 5.010001 && "$]" < 5.041000) ? sub(){1} : sub(){0};
+  my $category
+    = "$]" >= 5.041000 ? undef
+    : "$]" >= 5.037011 ? 'deprecated::smartmatch'
+    : "$]" >= 5.017011 ? 'experimental::smartmatch'
+    : undef;
+  *_SMARTMATCH_WARNING_CATEGORY = sub(){$category};
+}
 
 use overload(
     '=='   => "num_eq",
@@ -20,9 +29,9 @@ use overload(
     'lt'   => "str_lt",
     'bool' => "bool",
     '""'   => sub {shift},
+    ('~~' => 'match') x!! _WANT_SMARTMATCH,
 );
 
-use if ($] >= 5.010001), overload => '~~' => 'match';
 
 sub new { bless \@_, shift }
 
@@ -43,13 +52,18 @@ __END__
 
 =pod
 
-=head1 NAME
+=encoding UTF-8
 
-Syntax::Keyword::Junction::Base
+=for :stopwords Arthur Axel "fREW" Schmidt Carl Franks
 
-=head1 VERSION
+=head1 BUGS
 
-version 0.003007
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/haarg/Syntax-Keyword-Junction/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 AUTHORS
 
@@ -67,7 +81,7 @@ Carl Franks
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2024 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
